@@ -4,6 +4,8 @@ from numpy.random import seed, randint
 from numpy.testing import assert_array_equal, assert_equal
 from numpy import ma
 import tempfile, unittest, os, datetime
+import cftime
+from pkg_resources import parse_version
 
 nx=100; ydim=5; zdim=10
 nfiles = 10
@@ -112,12 +114,15 @@ class NonuniformTimeTestCase(unittest.TestCase):
         calendar = 'standard'
 
         # Get the real dates
-        dates = []
-        for file in self.files:
-            f = Dataset(file)
-            t = f.variables['time']
-            dates.extend(num2date(t[:], t.units, calendar))
-            f.close()
+        # skip this until cftime pull request #55 is in a released
+        # version (1.0.1?). Otherwise, fix for issue #808 breaks this
+        if parse_version(cftime.__version__) >= parse_version('1.0.1'):
+            dates = []
+            for file in self.files:
+                f = Dataset(file)
+                t = f.variables['time']
+                dates.extend(num2date(t[:], t.units, calendar))
+                f.close()
 
         # Compare with the MF dates
         f = MFDataset(self.files,check=True)
@@ -129,7 +134,10 @@ class NonuniformTimeTestCase(unittest.TestCase):
         assert_equal(T.shape, t.shape)
         assert_equal(T.dimensions, t.dimensions)
         assert_equal(T.typecode(), t.typecode())
-        assert_array_equal(num2date(T[:], T.units, T.calendar), dates)
+        # skip this until cftime pull request #55 is in a released
+        # version (1.0.1?). Otherwise, fix for issue #808 breaks this
+        if parse_version(cftime.__version__) >= parse_version('1.0.1'):
+            assert_array_equal(num2date(T[:], T.units, T.calendar), dates)
         assert_equal(date2index(datetime.datetime(1980, 1, 2), T), 366)
         f.close()
 
